@@ -12,11 +12,11 @@ use Moose::Util::TypeConstraints;
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.11';
+our $VERSION = '0.20';
 
 has file => (is => 'ro', lazy => 1, default => sub {
     my $self = shift;
-    my $meth = $self->context . '_file';
+    my $meth = ($self->context || 'local') . '_file';
     return $self->sqitch->config->$meth;
 });
 
@@ -34,8 +34,8 @@ has action  => (is => 'ro', isa => enum([qw(
     rename-section
     remove-section
 )]));
-has context => (is => 'ro', required => 1, default => 'project', isa => enum([qw(
-    project
+has context => (is => 'ro', isa => maybe_type enum([qw(
+    local
     user
     system
 )]));
@@ -44,6 +44,7 @@ has type => (is => 'ro', isa => enum([qw(int num bool bool-or-int)]));
 sub options {
     return qw(
         file|config-file|f=s
+        local
         user
         system
 
@@ -70,7 +71,7 @@ sub configure {
     my ($class, $config, $opt) = @_;
 
     # Make sure we are accessing only one file.
-    my @file = grep { $opt->{$_} }  qw(user system file);
+    my @file = grep { $opt->{$_} }  qw(local user system file);
     $class->usage('Only one config file at a time.') if @file > 1;
 
     # Make sure we have only one type.
@@ -94,7 +95,7 @@ sub configure {
     $class->usage('Only one action at a time.') if @action > 1;
 
     # Get the action and context.
-    my $context = first { $opt->{$_} } qw(user system);
+    my $context = first { $opt->{$_} } qw(local user system);
 
     # Make it so.
     return {
@@ -272,9 +273,9 @@ sub unset_all {
 
 sub list {
     my $self = shift;
-    my $config = $self->context eq 'project'
-        ? $self->sqitch->config
-        : $self->_file_config;
+    my $config = $self->context
+        ? $self->_file_config
+        : $self->sqitch->config;
     $self->emit(scalar $config->dump) if $config;
     return $self;
 }
@@ -342,7 +343,7 @@ __END__
 
 =head1 Name
 
-App::Sqitch::Command::config - Get and set project, user, or system Sqitch options
+App::Sqitch::Command::config - Get and set local, user, or system Sqitch options
 
 =head1 Synopsis
 
@@ -437,7 +438,7 @@ The configuration file context. Must be one of:
 
 =over
 
-=item * C<project>
+=item * C<local>
 
 =item * C<user>
 
@@ -445,8 +446,6 @@ The configuration file context. Must be one of:
 
 =back
 
-Defaults to C<project>.
-
 =item C<type>
 
 The type to cast a value to be set to or fetched as. May be one of:
@@ -561,16 +560,17 @@ Removes a section. Exits with an error if the section does not exist.
 
   $config->list;
 
-Lists all of the values in the configuration. If the context is C<system> or
-C<user>, only the settings set for that context will be emitted. Otherwise,
-all settings will be listed.
+Lists all of the values in the configuration. If the context is C<local>,
+C<user>, or C<system>, only the settings set for that context will be emitted.
+Otherwise, all settings will be listed.
 
 =head3 C<edit>
 
   $config->edit;
 
 Opens the context-specific configuration file in a text editor for direct
-editing. The editor is determined by L<Sqitch/editor>.
+editing. If no context is specified, the local config file will be opened. The
+editor is determined by L<Sqitch/editor>.
 
 =head2 Instance Accessors
 
@@ -579,9 +579,9 @@ editing. The editor is determined by L<Sqitch/editor>.
   my $file_name = $config->file;
 
 Returns the path to the configuration file to be acted upon. If the context is
-C<system>, then the value returned is C<$(prefix)/etc/sqitch.ini>. If the
-context is C<user>, then the value returned is C<~/.sqitch.config.ini>.
-Otherwise, the default is F<./sqitch.ini>.
+C<system>, then the value returned is C<$($etc_prefix)/sqitch.conf>. If the
+context is C<user>, then the value returned is C<~/.sqitch/sqitch.conf>.
+Otherwise, the default is F<./sqitch.conf>.
 
 =head1 See Also
 
@@ -603,8 +603,6 @@ The Sqitch command-line client.
 
 =item * Make exit codes the same as C<git-config>.
 
-=item * Implement C<--local>.
-
 =back
 
 =head1 Author
